@@ -47,9 +47,21 @@ def tensor_to_array(x):
     elif isinstance(x, list):
         return [tensor_to_array(e) for e in x]
     else:
-        raise TypeError('Found unsupported type')
+        raise TypeError('Found unsupported type ', type(x))
 
 
+def isnotebook():
+    # Check if running in ipython/jupyter notebook environment
+    try:
+        shell = get_ipython().__class__.__name__
+        if shell == 'ZMQInteractiveShell':
+            return True   # Jupyter notebook or qtconsole
+        elif shell == 'TerminalInteractiveShell':
+            return False  # Terminal running IPython
+        else:
+            return False  # Other type (?)
+    except NameError:
+        return False      # Probably standard Python interpreter
 
 
 if __name__ == '__main__':
