@@ -1,6 +1,6 @@
 import numpy as np
 import matplotlib
-from matplotlib import colors, animation, pyplot as plt
+from matplotlib import colors, animation, pyplot as plt, rcParams
 # from PIL import Image
 from .utils import isinteger, within_0_1, within_0_255, isnotebook
 from .config import config
@@ -18,6 +18,13 @@ logger = logging.getLogger('TorchShow')
 IMAGENET_MEAN = [0.485, 0.456, 0.406]
 IMAGENET_STD = [0.229, 0.224, 0.225]
 
+AXES_TITLE_FONTDICT = {'fontsize': rcParams['axes.titlesize'],
+                       'fontweight': rcParams['axes.titleweight'],
+                       'color': rcParams['axes.titlecolor'],
+                       'verticalalignment': 'bottom',
+                       'horizontalalignment': 'center'}
+
+
 def create_color_map(N=256, normalized=False):
     
     def bitget(byteval, idx):
@@ -39,7 +46,10 @@ def create_color_map(N=256, normalized=False):
     cmap = cmap/255 if normalized else cmap
     return cmap
 
-def set_title(fig, title):
+def set_window_title(fig, title):
+    """
+    Set the title of the figure window (effective when using a interactive backend.)
+    """
     # fig.canvas.set_window_title(title)
     if matplotlib.__version__ < '3.4':
         fig.canvas.set_window_title(title)
@@ -101,12 +111,20 @@ def display_plt(vis_list, **kwargs):
     ncols = max([len(l) for l in vis_list])
     show_axis = kwargs.get('show_axis', False)
     tight_layout = kwargs.get('tight_layout', True)
-    show_title = kwargs.get('show_title', False)
-    title_pattern = kwargs.get('title_pattern', "{img_id}")
+    suptitle = kwargs.get('suptitle', None)
+    axes_title = kwargs.get('axes_title', None)
+    # show_title = kwargs.get('show_title', False)
+    # title_pattern = kwargs.get('title_pattern', "{img_id}")
+    figsize = kwargs.get('figsize', None)
+    dpi = kwargs.get('dpi', None)
     title_namespace = {}
     
-    fig, axes = plt.subplots(nrows=nrows, ncols=ncols, squeeze=False)
-    set_title(fig, 'TorchShow')
+    fig = plt.figure(figsize=figsize, dpi=dpi)
+    axes = fig.subplots(nrows=nrows, ncols=ncols, squeeze=False)
+    # fig, axes = plt.subplots(nrows=nrows, ncols=ncols, squeeze=False)
+    set_window_title(fig, 'TorchShow')
+    if suptitle:
+        fig.suptitle(suptitle)
     
     for i, plots_per_row in enumerate(vis_list):
         for j, vis in enumerate(plots_per_row):
@@ -114,12 +132,15 @@ def display_plt(vis_list, **kwargs):
             imshow(axes[i,j], vis)
             title_namespace["img_id"] = i*ncols+j
             title_namespace["img_id_from_1"] = title_namespace["img_id"] + 1
-            if show_title:
-                axes[i, j].set_title(title_pattern.format(**title_namespace))
+            title_namespace["row"] = i
+            title_namespace["column"] = j
+            if axes_title is not None:
+                axes[i, j].set_title(axes_title.format(**title_namespace))
            
-    for ax in axes.ravel():
-        if not show_axis:
+    if not show_axis:
+        for ax in axes.ravel():
             ax.axis('off')
+            
     if tight_layout:
         fig.tight_layout()
     
@@ -133,7 +154,7 @@ def display_plt(vis_list, **kwargs):
         if dirname != '':
             os.makedirs(dirname, exist_ok=True)
         fig.savefig(file_path, bbox_inches = 'tight', pad_inches=0)
-        return
+        plt.close(fig)
     
     if not isnotebook():
         plt.show()
@@ -149,13 +170,21 @@ def animate_plt(video_list, **kwargs):
     ncols = max([len(l) for l in video_list[0]])
     
     show_axis = kwargs.get('show_axis', False)
-    # tight_layout = kwargs.get('tight_layout', True)
+    tight_layout = kwargs.get('tight_layout', True)
+    suptitle = kwargs.get('suptitle', None)
     # show_title = kwargs.get('show_title', False)
     # title_pattern = kwargs.get('title_pattern', "{img_id}")
     # title_namespace = {}
+    figsize = kwargs.get('figsize', None)
+    dpi = kwargs.get('dpi', None)
     
-    fig, axes = plt.subplots(nrows=nrows, ncols=ncols, squeeze=False)
-    set_title(fig, 'TorchShow')
+    fig = plt.figure(figsize=figsize, dpi=dpi)
+    axes = fig.subplots(nrows=nrows, ncols=ncols, squeeze=False)
+    # fig, axes = plt.subplots(nrows=nrows, ncols=ncols, squeeze=False)
+    set_window_title(fig, 'TorchShow')
+    if suptitle:
+        fig.suptitle(suptitle)
+
     plots = []
     
     # Initialization
@@ -167,9 +196,12 @@ def animate_plt(video_list, **kwargs):
             else:
                 plots.append(None)
     
-    for ax in axes.ravel():
-        if not show_axis:
+    if not show_axis:
+        for ax in axes.ravel():
             ax.axis('off')
+            
+    if tight_layout:
+        fig.tight_layout()            
     
     def run(frames_at_t):
         for i, plots_per_row in enumerate(frames_at_t):
@@ -330,7 +362,7 @@ def vis_categorical_mask(x, max_N=256, **kwargs):
     N = int(x.max()) + 1
     
     if x.max() > max_N:
-        warnings.warn('The maximum value in input is {} which is greater than the default max_N ({}), TensorShow will automatically adjust max_N to {}.'.format(x.max(), max_N, x.max()))
+        warnings.warn('The maximum value in input is {} which is greater than the default max_N ({}). Automatically adjust max_N to {}.'.format(x.max(), max_N, x.max()))
         max_N = x.max() + 1
         
     color_list = create_color_map(N=max_N, normalized=True)
